@@ -11,14 +11,18 @@
 #include <stdlib.h>
 #include <string.h>
 
+#ifndef XC_WIN32
 #include <X11/Intrinsic.h>
 #include <X11/StringDefs.h>
+#endif
 
 #ifdef TCL_WRAPPER 
 #include <tk.h>
 #else
+#ifndef XC_WIN32
 #include "Xw/Xw.h"
 #endif
+#endif
 
 /*----------------------------------------------------------------------*/
 /* Local includes                                                       */
@@ -516,7 +520,7 @@ Boolean labeltext(int keypressed, char *clientdata)
    labelptr curlabel;
    stringpart *curpos, *labelbuf;
    int locpos;
-   Boolean r, do_redraw = False;
+   Boolean r = True, do_redraw = False;
    short tmplength, tmpheight, cfont;
    TextExtents tmpext;
 
@@ -812,15 +816,23 @@ Boolean labeltext(int keypressed, char *clientdata)
 	    strcpy(newpart->data.string, clientdata);
 	    ops = match_param(topobject, clientdata);
 	    if (ops == NULL) errcond = True;
+	    else {
+	       /* Forward edit cursor position to the end of the parameter */
+	       do {
+	          textpos++;
+	          curpos = findstringpart(textpos, &locpos, curlabel->string,
+	 		areawin->topinstance);
+	       } while (curpos->type != PARAM_END);
+	    }
 	    break;
       }
       if (errcond == True) {
 	 Wprintf("Error in insertion.  Ignoring.");
 	 deletestring(newpart, &curlabel->string, areawin->topinstance);
+	 r = FALSE;
       }
       else {
          textpos++;
-	 r = TRUE;
       }
       do_redraw = True;
    }
@@ -1985,6 +1997,21 @@ void wire_op(int op, int x, int y)
 
    if (newwire) {
       if (op == XCF_Finish_Element) {
+
+	 /* If the last points are the same, remove all redundant ones.	*/
+	 /* This avoids the problem of extra points when people do left	*/
+	 /* click followed by middle click to finish (the redundant way	*/
+	 /* a lot of drawing programs work).				*/
+
+	 XPoint *t2pt;
+	 while (newwire->number > 2) {
+	    tpoint = newwire->points + newwire->number - 1;
+	    t2pt = newwire->points + newwire->number - 2;
+	    if (tpoint->x != t2pt->x || tpoint->y != t2pt->y)
+	       break;
+	    newwire->number--;
+	 }
+
          XcSetFunction(GXcopy);
          XcSetForeground(newwire->color);
 	 topobject->parts++;
