@@ -11,13 +11,17 @@
 #include <string.h>
 #include <stdlib.h>
 
+#ifndef XC_WIN32
 #include <X11/Intrinsic.h>
 #include <X11/StringDefs.h>
+#endif
 #ifdef TCL_WRAPPER 
 #include <tk.h>
 #else
+#ifndef XC_WIN32
 #include "Xw/Xw.h"
 #endif
+#endif
 
 #include <math.h>
 
@@ -182,7 +186,7 @@ short *pagetotals(int page, short mode)
    int i;
    short *counts, *icount, *result;
 
-   if (xobjs.pagelist[page]->pageinst == NULL) return;
+   if (xobjs.pagelist[page]->pageinst == NULL) return NULL;
 
    counts = (short *)malloc(xobjs.pages * sizeof(short));
    icount = (short *)malloc(xobjs.pages * sizeof(short));
@@ -1215,7 +1219,7 @@ void linkedlistinsertafter(liblistptr *spec, int o1, int o2)
 /* in that library has changed.				*/
 /*------------------------------------------------------*/
 
-void lib_set_changes(libnum)
+void lib_set_changes(int libnum)
 {
    int j;
    objectptr thisobj;
