@@ -14,9 +14,11 @@
 #include <errno.h>
 #include <limits.h>
 
+#ifndef XC_WIN32
 #include <X11/Intrinsic.h>
 #include <X11/StringDefs.h>
 #include <X11/Xutil.h>
+#endif
 
 #ifdef TCL_WRAPPER
 #include <tk.h>
@@ -319,13 +321,16 @@ float parseunits(char *strptr)
 /* Set the output page size, in the current unit of measure	*/
 /* Return value:  TRUE if _STR2 values were in inches, FALSE	*/
 /* if in centimeters.						*/
+/* XXX This API gives no good way to signal errors.             */
 /*--------------------------------------------------------------*/
 
 Boolean setoutputpagesize(XPoint *dataptr)
 {
    float px, py;
    char units[10], *expos;
+#ifndef TCL_WRAPPER
    Arg wargs[1];
+#endif
 
    strcpy(units, "in");
 
@@ -333,14 +338,14 @@ Boolean setoutputpagesize(XPoint *dataptr)
       if (sscanf(_STR2, "%f %*c %f", &px, &py) < 3) {
 	 if ((expos = strchr(_STR2, 'x')) == NULL) {
             Wprintf("Illegal Form for page size.");
-	    return;
+	    return FALSE;
 	 }
 	 else {
 	    *expos = '\0';
 	    if (sscanf(_STR2, "%f", &px) == 0 ||
 		  sscanf(expos + 1, "%f %9s", &py, units) == 0) {
                Wprintf("Illegal Form for page size.");
-	       return;
+	       return FALSE;
 	    }
 	 }
       }
@@ -351,7 +356,7 @@ Boolean setoutputpagesize(XPoint *dataptr)
 
    if ((px <= 2.0) || (py <= 2.0)) {
       Wprintf("Page size too small for margins.");
-      return;
+      return FALSE;
    }
 
    dataptr->x = (short)(px * 72.0);
@@ -738,7 +743,9 @@ void newpagemenu(xcWidget w, pointertype value, caddr_t nulldata)
 int createlibrary(Boolean force)
 {
    xcWidget libmenu, newbutton, oldbutton;
+#ifndef TCL_WRAPPER
    Arg wargs[2];
+#endif
    char libstring[20];
    int libnum;
    objectptr newlibobj;
