@@ -289,6 +289,10 @@ menustruct WindowMenu[] = {
 };
 
 menustruct FileMenu[] = {
+#ifdef XC_WIN32
+	{"New window", action(win32_new_window, NULL)},
+	{" ", noaction},
+#endif
 	{"Read Xcircuit File", action(getfile, Number(NORMAL))},
 	{"Import Xcircuit PS", action(getfile, Number(IMPORT))},
 	{"Import background PS", action(getfile, Number(PSBKGROUND))},
