@@ -12,14 +12,18 @@
 #include <stdlib.h>
 #include <string.h>
 
+#ifndef XC_WIN32
 #include <X11/Intrinsic.h>
 #include <X11/StringDefs.h>
+#endif
 
 #ifdef TCL_WRAPPER 
 #include <tk.h>
 #else
+#ifndef XC_WIN32
 #include "Xw/Xw.h"
 #endif
+#endif
 
 /*----------------------------------------------------------------------*/
 /* Local includes							*/
@@ -42,7 +46,9 @@ extern Tcl_Interp *xcinterp;
 #endif
 extern Globaldata xobjs;
 extern XCWindowData *areawin;
+#ifndef TCL_WRAPPER
 extern Widget     menuwidgets[];
+#endif
 extern short textpos, textend;
 extern char _STR[150];
 
@@ -71,10 +77,14 @@ u_char param_select[] = {
 };
 
 #ifdef TCL_WRAPPER
+#ifndef _MSC_VER
 xcWidget *param_buttons[] = {
    /* To be done---map buttons to Tk_Windows! */
 };
 #else
+xcWidget *param_buttons[];
+#endif
+#else
 Widget *param_buttons[] = {
    &ParametersNumericButton,		/* P_NUMERIC */
    &ParametersSubstringButton,		/* P_SUBSTRING */
@@ -211,7 +221,7 @@ oparamptr find_param(objinstptr thisinst, char *key)
    oparamptr fparam, ops;
    fparam = match_instance_param(thisinst, key);
    ops = match_param(thisinst->thisobject, key);
-   if ((fparam == NULL) || (ops->type == XC_EXPR) && (fparam->type != XC_EXPR))
+   if ((fparam == NULL) || ((ops->type == XC_EXPR) && (fparam->type != XC_EXPR)))
       fparam = ops;
    return fparam;
 }
@@ -1576,8 +1586,16 @@ void unmakenumericalp(genericptr *gelem, u_int mode)
    }
 }
 
+#ifndef TCL_WRAPPER
+
 /*--------------------------------------------------------------*/
 /* Insert an existing parameter into a string.			*/
+/* This code needs to be replaced in the non-Tcl version with	*/
+/* a new pop-up window using a callback to labeltext().		*/
+/*								*/
+/* This routine has been replaced in the Tcl version with a	*/
+/* callback to command "label insert parameter" from the 	*/
+/* parameter-select pop-up window.				*/
 /*--------------------------------------------------------------*/
 
 void insertparam()
@@ -1586,6 +1604,9 @@ void insertparam()
    oparamptr ops;
    int result, nparms;
    char *selparm;
+   char *newstr, *sptr;
+   char *sstart = (char *)malloc(1024);
+   oparamptr chosen_ops=NULL;
 
    /* Don't allow nested parameters */
 
@@ -1595,63 +1616,44 @@ void insertparam()
       return;
    }
 
-#ifdef TCL_WRAPPER
-
-   /* The Tcl version uses a GUI selection mechanism. */
-
-   result = Tcl_Eval(xcinterp, "xcircuit::promptselectparam");
-   if (result != TCL_OK) {
-      Tcl_SetResult(xcinterp, "Error in executing promptselectparam", NULL);
-      return;
-   }
-   selparm = Tcl_GetString(Tcl_GetObjResult(xcinterp));
-
-   ops = match_param(topobject, selparm);
-   if (ops == NULL)
-   {
-       Tcl_SetResult(xcinterp, "No such parameter.", NULL);
-       selparm = NULL;
-   }
-
-#else
-
-   /* First pass is to check how many string parameters there are:	*/
-   /* If only one, then automatically use it.  Otherwise, prompt	*/
-   /* for which parameter to use.					*/
-
-   for (ops = topobject->params; ops != NULL; ops = ops->next)
-      if (ops->type == XC_STRING)
+   nparms = 0;
+   strcpy(sstart, "Choose: ");
+   sptr = sstart + 8;
+   for (ops = topobject->params; ops != NULL; ops = ops->next) {
+      if (ops->type == XC_STRING) {
+	 chosen_ops = ops;
 	 nparms++;
+	 if (nparms != 1) {
+	    strcat(sptr, ", ");
+	    sptr += 2;
+	 }
+	 newstr = stringprint(ops->parameter.string, NULL);
+	 sprintf(sptr, "%d = %s = <%s", nparms, ops->key, newstr);
+	 free(newstr);
+	 newstr = NULL;
+         sptr += strlen(sptr);
+      }
+   }
+
+   /* If only one parameter, then automatically use it.  Otherwise,  */
+   /* prompt for which parameter to use.                             */
 
    if (nparms > 1) {
-      char *newstr, *sptr;
-      char *sstart = (char *)malloc(1024);
-      nparms = 0;
-      strcpy(sstart, "Choose: ");
-      sptr = sstart + 8;
+      int i=0, select_int;
+      chosen_ops = NULL;
+      Wprintf("%s", sstart);
+      select_int = getkeynum();
       for (ops = topobject->params; ops != NULL; ops = ops->next) {
 	 if (ops->type == XC_STRING) {
-	    nparms++;
-	    if (nparms != 1) {
-	       strcat(sptr, ", ");
-	       sptr += 2;
-	    }
-	    sprintf(sptr, "%s = <", ops->key);
-	    newstr = stringprint(ops->parameter.string, NULL);
-	    strcat(sptr, newstr);
-	    free(newstr);
-	    newstr = NULL;
-            sptr += strlen(sptr);
+	    if (i==select_int) chosen_ops = ops;
+	    i++;
 	 }
       }
-      Wprintf("%s", sstart);
-      free(sstart);
-
-      /* Need a new non-Tcl version method . . . */
-      ops = NULL;	/* placeholder */
    }
 
-#endif
+   free(sstart);
+   ops = chosen_ops;
+   if (ops != NULL) selparm = ops->key;
 
    if (ops != NULL)
       labeltext(PARAM_START, selparm);
@@ -1659,6 +1661,8 @@ void insertparam()
       Wprintf("No such parameter.");
 }
 
+#endif
+
 /*--------------------------------------------------------------*/
 /* Parameterize a label string.					*/
 /*--------------------------------------------------------------*/
