@@ -161,7 +161,7 @@ static PyObject *pypopupprompt(PyObject *self, PyObject *args,
 
 
    savebutton = getgeneric(NULL, NULL, (void *)pfunction);
-   popupprompt(areawinarea, (char *)prompt, displaystr,
+   popupprompt(areawin->area, (char *)prompt, displaystr,
 		pypromptvalue, savebutton, dofile);
 
    return PyInt_FromLong(0L);
@@ -420,7 +420,7 @@ stringpart *PySetStringParts(PyObject *dval)
       if (PyDict_Check(litem)) {
 	 if ((ditem = PyDict_GetItemString(litem, "Parameter")) != NULL) {
 	    newpart->type = PARAM_START;
-	    newpart->data.paramno = (int)PyInt_AsLong(ditem);
+	    newpart->data.string = strdup(PyString_AsString(ditem));
 	 }
 	 else if ((ditem = PyDict_GetItemString(litem, "Font")) != NULL) {
 	    newpart->type = FONT_NAME;
@@ -523,7 +523,7 @@ PyObject *PyGetStringParts(stringpart *thisstring)
 	 case PARAM_START:
 	    sdict = PyDict_New();
 	    PyDict_SetItem(sdict, PyString_FromString("Parameter"),
-		  PyInt_FromLong((long)strptr->data.paramno));
+		  PyString_FromString(strptr->data.string));
 	    PyList_SetItem(lstr, i, sdict);
 	    break;
 	 case PARAM_END:
@@ -605,14 +605,15 @@ PyObject *PyGetStringParts(stringpart *thisstring)
 genericptr *CheckHandle(PyObject *ehandle)
 {
    genericptr *gelem;
-   int i, j, eaddr;
+   int i, j;
+   long int eaddr;
    objectptr thisobj;
    Library *thislib;
 
-   eaddr = (int)PyInt_AsLong(ehandle);
+   eaddr = PyInt_AsLong(ehandle);
    for (gelem = topobject->plist; gelem < topobject->plist +
 	topobject->parts; gelem++)
-      if ((int)(*gelem) == eaddr) goto exists;
+      if ((long int)(*gelem) == eaddr) goto exists;
 
    /* Okay, it isn't in topobject.  Try all other pages. */
 
@@ -620,7 +621,7 @@ genericptr *CheckHandle(PyObject *ehandle)
       if (xobjs.pagelist[i]->pageinst == NULL) continue;
       thisobj = xobjs.pagelist[i]->pageinst->thisobject;
       for (gelem = thisobj->plist; gelem < thisobj->plist + thisobj->parts; gelem++)
-         if ((int)(*gelem) == eaddr) goto exists;
+         if ((long int)(*gelem) == eaddr) goto exists;
    }
 
    /* Still not found?  Maybe in a library */
@@ -630,7 +631,7 @@ genericptr *CheckHandle(PyObject *ehandle)
       for (j = 0; j < thislib->number; j++) {
          thisobj = thislib->library[j];
          for (gelem = thisobj->plist; gelem < thisobj->plist + thisobj->parts; gelem++)
-            if ((int)(*gelem) == eaddr) goto exists;
+            if ((long int)(*gelem) == eaddr) goto exists;
       }
    }
 
@@ -648,9 +649,10 @@ exists:
 
 objectptr CheckPageHandle(PyObject *ehandle)
 {
-   int eaddr, pageno;
+   int pageno;
+   long int eaddr;
 
-   eaddr = (int)PyInt_AsLong(ehandle);
+   eaddr = PyInt_AsLong(ehandle);
    pageno = is_page((objectptr)eaddr);
    if (pageno < 0) return NULL;
    return (objectptr)eaddr;
@@ -681,7 +683,7 @@ static PyObject *xc_getpage(PyObject *self, PyObject *args)
 {
    Pagedata *thispage;
    PyObject *rdict, *dlist;
-   int pageno = areawinpage + 1, i;
+   int pageno = areawin->page + 1, i;
 
    if (!PyArg_ParseTuple(args, "|d:getpage", &pageno))
       return NULL;
@@ -855,7 +857,7 @@ static PyObject *xc_getobject(PyObject *self, PyObject *args)
 
    nparam = get_num_params(thisobj);
    if (nparam > 0) {
-      dlist = PyList_New(nparams);
+      dlist = PyList_New(nparam);
       i = 0;
       for (ops = thisobj->params; ops != NULL; ops = ops->next) {
 	 i++;
@@ -893,7 +895,7 @@ static PyObject *xc_netlist()
 {
    PyObject *rdict = NULL;
 
-   if (updatenets(areawintopinstance) <= 0) {
+   if (updatenets(areawin->topinstance, FALSE) <= 0) {
       PyErr_SetString(PyExc_TypeError, "Error:  Check circuit for infinite recursion.");
       return NULL;
    }
@@ -914,10 +916,10 @@ static PyObject *xc_load(PyObject *self, PyObject *args)
    int pageno = 0, savepage;
 
    if (!PyArg_ParseTuple(args, "s|i:load", &filename, &pageno))
-      return PyInt_FromLong((long)areawinpage);
+      return PyInt_FromLong((long)areawin->page);
 
-   if (--pageno < 0) pageno = areawinpage;
-   savepage = areawinpage;
+   if (--pageno < 0) pageno = areawin->page;
+   savepage = areawin->page;
 
    strcpy(_STR2, filename);
    if (savepage != pageno) newpage(pageno);
@@ -936,7 +938,7 @@ static PyObject *xc_page(PyObject *self, PyObject *args)
    int pageno;
 
    if (!PyArg_ParseTuple(args, "i:page", &pageno))
-      return PyInt_FromLong((long)areawinpage);
+      return PyInt_FromLong((long)areawin->page);
 
    newpage(pageno - 1);
    return PyInt_FromLong((long)pageno);
@@ -958,18 +960,18 @@ static PyObject *xc_zoom(PyObject *self, PyObject *args)
       return NULL;
    }
    
-   save = areawinzoomfactor;
+   save = areawin->zoomfactor;
 
    if (factor < 1.0) {
-      areawinzoomfactor = 1.0 / factor;
-      zoomout(NULL, NULL, NULL);
+      areawin->zoomfactor = 1.0 / factor;
+      zoomout(0, 0);	/* Needs to be fixed---give x, y for drag fn */
    }
    else {
-      areawinzoomfactor = factor;
-      zoomin(NULL, NULL, NULL);
+      areawin->zoomfactor = factor;
+      zoomin(0, 0);	/* Needs to be fixed---see above */
    }
 
-   areawinzoomfactor = save;
+   areawin->zoomfactor = save;
    return PyFloat_FromDouble((double)topobject->viewscale);
 }
 
@@ -981,7 +983,6 @@ static PyObject *xc_pan(PyObject *self, PyObject *args)
 {
    PyObject *cornerpos, *xobj, *yobj = NULL, *pval;
    int x, y;
-   XButtonEvent bevent;
    XPoint upoint, wpoint;
 
    if (!PyArg_ParseTuple(args, "O|O:pan", &xobj, &yobj))
@@ -1002,13 +1003,11 @@ static PyObject *xc_pan(PyObject *self, PyObject *args)
    }
 
    user_to_window(upoint, &wpoint);
-   bevent.x = wpoint.x;
-   bevent.y = wpoint.y;
-   panbutton((u_int)5, &bevent);
+   panbutton((u_int)5, wpoint.x, wpoint.y, 0.33);  /* fixed fraction */
 
    cornerpos = PyTuple_New(2);
-   PyTuple_SetItem(cornerpos, 0, PyInt_FromLong((long)areawinpcorner->x));
-   PyTuple_SetItem(cornerpos, 1, PyInt_FromLong((long)areawinpcorner->y));
+   PyTuple_SetItem(cornerpos, 0, PyInt_FromLong((long)areawin->pcorner.x));
+   PyTuple_SetItem(cornerpos, 1, PyInt_FromLong((long)areawin->pcorner.y));
 
    return cornerpos;
 }
@@ -1022,8 +1021,8 @@ static PyObject *xc_getwindow()
    PyObject *windowsize;
 
    windowsize = PyTuple_New(2);
-   PyTuple_SetItem(windowsize, 0, PyInt_FromLong((long)areawinwidth));
-   PyTuple_SetItem(windowsize, 1, PyInt_FromLong((long)areawinheight));
+   PyTuple_SetItem(windowsize, 0, PyInt_FromLong((long)areawin->width));
+   PyTuple_SetItem(windowsize, 1, PyInt_FromLong((long)areawin->height));
 
    return windowsize;
 }
@@ -1413,7 +1412,7 @@ static PyObject *xc_setattr(PyObject *self, PyObject *args)
 	 break;
    }
 
-   calcbbox(areawintopinstance);
+   calcbbox(areawin->topinstance);
    return PyInt_FromLong((long)(*gelem));
 }
 /*--------------------------------------------------------------*/
@@ -1426,7 +1425,7 @@ static PyObject *xc_set(PyObject *self, PyObject *args)
    const char *sarg1, *sarg2;
    int i;
    Boolean a = True; 
-   short cpage = areawinpage;
+   short cpage = areawin->page;
 
    if (!PyArg_ParseTuple(args, "ss:set", &sarg1, &sarg2))
       return NULL;
@@ -1447,26 +1446,26 @@ static PyObject *xc_set(PyObject *self, PyObject *args)
 
       for (i = 0; i < fontcount; i++) {
 	 if (!strcmp(fonts[i].psname, sarg2)) {
-            areawinpsfont = i;
+            areawin->psfont = i;
             setdefaultfontmarks();
 	    break;
 	 }
       }
    }
    else if (!strcmp(sarg1, "fontscale")) {
-      sscanf(sarg2, "%f", &areawintextscale);
+      sscanf(sarg2, "%f", &areawin->textscale);
    }
    else if (!strcmp(sarg1, "axis") || !strcmp(sarg1, "axes")) {
-      areawinaxeson = a;
-      toggle(GridAxesButton, &areawinaxeson, NULL);
+      areawin->axeson = a;
+      toggle(GridAxesButton, (pointertype)&areawin->axeson, NULL);
    }
    else if (!strcmp(sarg1, "grid")) {
-      areawingridon = a;
-      toggle(GridGridButton, &areawingridon, NULL);
+      areawin->gridon = a;
+      toggle(GridGridButton, (pointertype)&areawin->gridon, NULL);
    }  
    else if (!strcmp(sarg1, "snap") || !strcmp(sarg1, "snap-to")) {
-      areawinsnapto = a;
-      toggle(SnaptoSnaptoButton, &areawinsnapto, NULL);
+      areawin->snapto = a;
+      toggle(SnaptoSnaptoButton, (pointertype)&areawin->snapto, NULL);
    }
    else if (!strcmp(sarg1, "gridspace")) {
       sscanf(sarg2, "%f", &xobjs.pagelist[cpage]->gridspace);
@@ -1488,12 +1487,12 @@ static PyObject *xc_set(PyObject *self, PyObject *args)
       else if (!strcmp(sarg2, "normal")) boxedit(NULL, NORMAL, NULL);
    }
    else if (!strcmp(sarg1, "linewidth")) {
-      sscanf(sarg2, "%f", &areawinlinewidth);
+      sscanf(sarg2, "%f", &areawin->linewidth);
    }
    else if (!strcmp(sarg1, "colorscheme")) {
       if (!strcmp(sarg2, "inverse"))
-         areawininvert = False;
-      inversecolor(NULL, &areawininvert, NULL);
+         areawin->invert = False;
+      inversecolor(NULL, (pointertype)&areawin->invert, NULL);
    }
    else if (!strcmp(sarg1, "coordstyle")) {
       if (!strcmp(sarg2, "cm") || !strcmp(sarg2, "centimeters")) {
@@ -1515,7 +1514,7 @@ static PyObject *xc_set(PyObject *self, PyObject *args)
    }
 #ifdef HAVE_XPM
    else if (!strcmp(sarg1, "toolbar")) {
-      areawintoolbar_on = a;
+      areawin->toolbar_on = a;
       dotoolbar(OptionsDisableToolbarButton, NULL, NULL);
     }
 #endif
@@ -1691,7 +1690,7 @@ static PyObject *xc_unbind(PyObject *self, PyObject *args)
       flags |= KEYOVERRIDE;
    }
 
-   remove_keybinding(keyname, function);
+   remove_keybinding(areawin->area, keyname, function);
    return PyString_FromString(keyname);
 }
 
@@ -1723,7 +1722,7 @@ static PyObject *xc_refresh(PyObject *self, PyObject *args)
       
    refresh(NULL, NULL, NULL);
 
-   while(XCheckWindowEvent(dpy, areawinareawin, ~NoEventMask, &event))
+   while (XCheckWindowEvent(dpy, areawin->window, ~NoEventMask, &event))
          XtDispatchEvent(&event);
 
    return PyInt_FromLong(0L);
@@ -1737,7 +1736,7 @@ int pybutton(Widget w, caddr_t clientdata, caddr_t calldata)
 {  
    int status;
 
-   sprintf(_STR2, "buttondict[%d]()\n", w);
+   sprintf(_STR2, "buttondict[%ld]()\n", (long int)w);
    status = PyRun_SimpleString(_STR2);
    refresh(NULL, NULL, NULL);
    return status;
@@ -1767,7 +1766,7 @@ static PyObject *xc_newbutton(PyObject *self, PyObject *args)
    }
    if (i == MaxMenuWidgets) {
       Wprintf("Cannot find specified menu.");
-      return;
+      return NULL;
    }
 
    XtnSetArg(XtNfont, appdata.xcfont);
@@ -1777,7 +1776,7 @@ static PyObject *xc_newbutton(PyObject *self, PyObject *args)
    XtAddCallback (newbutton, XtNselect, (XtCallbackProc)pybutton, newbutton);
    XtManageChild(newbutton);
 
-   sprintf(_STR2, "buttondict[%d] = %s\n", newbutton, pfunction);
+   sprintf(_STR2, "buttondict[%ld] = %s\n", (long int)newbutton, pfunction);
    status = PyRun_SimpleString(_STR2);
    return PyInt_FromLong((long)status);
 }
@@ -1792,7 +1791,7 @@ int pytool(Widget w, caddr_t clientdata, caddr_t calldata)
 {  
    int status;
 
-   sprintf(_STR2, "tooldict[%d]()\n", w);
+   sprintf(_STR2, "tooldict[%ld]()\n", (long int)w);
    status = PyRun_SimpleString(_STR2);
    refresh(NULL, NULL, NULL);
    return status;
@@ -1842,7 +1841,7 @@ static PyObject *xc_newtool(PyObject *self, PyObject *args)
    XtAddCallback (newtool, XtNselect, (XtCallbackProc)pybutton, newtool);
    XtManageChild(newtool);
 
-   sprintf(_STR2, "tooldict[%d] = %s\n", newtool, pfunction);
+   sprintf(_STR2, "tooldict[%ld] = %s\n", (long int)newtool, pfunction);
    status = PyRun_SimpleString(_STR2);
    return PyInt_FromLong((long)status);
 }
@@ -1882,7 +1881,7 @@ Widget *pytoolbuttons(int *num_tools)
          PyErr_Clear();
 	 return NULL;
       }
-      ptools[i] = (Widget)((int)PyInt_AsLong(rval));
+      ptools[i] = (Widget)PyInt_AsLong(rval);
       Py_DECREF(rval);
    }
    return ptools;
@@ -2069,15 +2068,15 @@ void loadrcfile()
 
    if (!(flags & FONTOVERRIDE)) {
       loadfontfile("Helvetica");
-      if (areawinpsfont == -1)
+      if (areawin->psfont == -1)
          for (i = 0; i < fontcount; i++)
 	    if (!strcmp(fonts[i].psname, "Helvetica")) {
-	       areawinpsfont = i;
+	       areawin->psfont = i;
 	       break;
 	    }
    }
 
-   if (areawinpsfont == -1) areawinpsfont = 0;
+   if (areawin->psfont == -1) areawin->psfont = 0;
 
    setdefaultfontmarks();
       
