@@ -36,6 +36,8 @@
 #include <errno.h>
 #include <limits.h>
 #include <locale.h>
+#include <ctype.h>
+#ifndef XC_WIN32
 #include <unistd.h>   /* for unlink() */
 
 #include <X11/Intrinsic.h>
@@ -45,10 +47,12 @@
 #include <X11/cursorfont.h>
 #include <X11/Xproto.h>
 #include <X11/Xatom.h>
+#endif
 
 #ifdef TCL_WRAPPER
 #include <tk.h>
 #else
+#ifndef XC_WIN32
 #include "Xw/Xw.h"
 #include "Xw/Form.h"
 #include "Xw/WorkSpace.h"
@@ -61,6 +65,14 @@
 #include "Xw/TextEdit.h"
 #include "Xw/Toggle.h"
 #endif
+#endif
+
+#if defined(XC_WIN32) && defined(TCL_WRAPPER)
+#include <X11/Xlib.h>
+#include <X11/Xutil.h>
+#include <X11/cursorfont.h>
+#include <X11/Xatom.h>
+#endif
 
 #ifndef P_tmpdir
 #define P_tmpdir TMPDIR
@@ -81,7 +93,9 @@
 #include "prototypes.h"
 
 #ifdef HAVE_XPM
+#ifndef XC_WIN32
 #include <X11/xpm.h>
+#endif
 #include "lib/pixmaps/xcircuit.xpm"
 #endif
 
@@ -151,7 +165,7 @@ void addtocolorlist(xcWidget button, int cvalue)
 
    /* Get and store the RGB values of the new color */
    
-   XQueryColor(dpy, cmap, &(colorlist[number_colors - 1].color));
+   XQueryColors(dpy, cmap, &(colorlist[number_colors - 1].color), 1);
 }
 
 /*----------------------------------------------------------------------*/
@@ -164,7 +178,9 @@ void addtocolorlist(xcWidget button, int cvalue)
 int addnewcolorentry(int ccolor)
 {
    xcWidget colormenu, newbutton;
+#ifndef XC_WIN32
    Arg wargs[2];
+#endif
    int i, n = 0;
 
    /* check to see if entry is already in the color list */
@@ -237,8 +253,14 @@ void quit(xcWidget w, caddr_t nulldata)
 
    if (xobjs.tempfile != NULL) {
       if (w != NULL) {
+#ifndef XC_WIN32
          if (unlink(xobjs.tempfile) < 0)
 	    Fprintf(stderr, "Error %d unlinking file \"%s\"\n", errno, xobjs.tempfile);
+#else
+         if (DeleteFile(xobjs.tempfile) != TRUE)
+	    Fprintf(stderr, "Error %d unlinking file \"%s\"\n",
+			GetLastError(), xobjs.tempfile);
+#endif
       }
       else
 	 Fprintf(stderr, "Ctrl-C exit:  reload workspace from \"%s\"\n",
@@ -251,6 +273,8 @@ void quit(xcWidget w, caddr_t nulldata)
    exit_interpreter();
 #elif defined(TCL_WRAPPER)
    exit(0);	/* For now, exit.  Later, clear all pages and return to interp. */
+#elif defined(XC_WIN32)
+   PostQuitMessage(0);
 #else
    exit(0);
 #endif
@@ -365,6 +389,7 @@ void quitcheck(xcWidget w, caddr_t clientdata, caddr_t calldata)
       Tcl_Eval(xcinterp, promptstr);
       Tcl_Eval(xcinterp, ".query.bbar.okay configure -command {quitnocheck}");
       Tcl_Eval(xcinterp, "wm deiconify .query");
+      Tcl_Eval(xcinterp, "raise .query");
       free(promptstr);
    }
    else {
@@ -476,7 +501,8 @@ void outputpopup(xcWidget button, caddr_t clientdata, caddr_t calldata)
 /* For formatted strings, format first into _STR   */
 /*-------------------------------------------------*/
 
-xcTimeOutProc clrmessage(caddr_t clientdata)
+/* XXX it looks like this routine is an orphan */
+void clrmessage(caddr_t clientdata)
 {
    char buf1[50], buf2[50];
 
@@ -612,6 +638,8 @@ int installowncmap()
 /* Find the nearest color in the colormap to cvexact and return its pixel value */
 /*------------------------------------------------------------------------------*/
 
+#if defined(TCL_WRAPPER) || !defined(XC_WIN32)
+
 int findnearcolor(XColor *cvexact)
 {
    /* find the nearest-matching color in the colormap */
@@ -661,6 +689,8 @@ int findnearcolor(XColor *cvexact)
    return minidx;
 }
 
+#endif
+
 /*------------------------------------------------------------------------------*/
 /* Layout colors which are defined from the Xdefaults (BBOXCOLOR, schematic	*/
 /* label colors) may be duplicated in the colormap.  This routine takes a color	*/
@@ -678,7 +708,7 @@ int xc_getlayoutcolor(int cidx)
    loccolor.pixel = cidx;
    loccolor.flags = DoRed | DoGreen | DoBlue;
 
-   XQueryColor(dpy, cmap, &loccolor);
+   XQueryColors(dpy, cmap, &loccolor, 1);
 
    locidx = rgb_alloccolor(loccolor.red, loccolor.green, loccolor.blue);
    return locidx;
@@ -695,6 +725,8 @@ int xc_getlayoutcolor(int cidx)
 /* converter until after XtInitialize(), when using the Xt (not Tcl) GUI.  */
 /*-------------------------------------------------------------------------*/
 
+#if defined(TCL_WRAPPER) || !defined(XC_WIN32)
+
 caddr_t CvtStringToPixel(XrmValuePtr args, int *nargs, XrmValuePtr fromVal,
 	XrmValuePtr toVal)
 {
@@ -721,10 +753,21 @@ caddr_t CvtStringToPixel(XrmValuePtr args, int *nargs, XrmValuePtr fromVal,
    return NULL;
 }
 
+#endif
+
 /*-------------------------------------------------------------------------*/
 /* Allocate new color using the CvtStringToPixel routine		   */
 /*-------------------------------------------------------------------------*/
 
+#if defined(XC_WIN32) && !defined(TCL_WRAPPER)
+
+int xc_alloccolor(char *name)
+{
+   return WinNamedColor(name);
+}
+
+#else
+
 int xc_alloccolor(char *name)
 {
    XrmValue fromC, toC;
@@ -739,6 +782,8 @@ int xc_alloccolor(char *name)
    return pixval;
 }
 
+#endif
+
 /*----------------------------------------------------------------------*/
 /* Check if color within RGB roundoff error exists in xcircuit's color	*/
 /* table.  Assume 24-bit color, in which resolution can be no less than	*/
@@ -775,6 +820,15 @@ int rgb_querycolor(int red, int green, int blue, int *pixval)
 /* Allocate new color from RGB values (e.g., from PS file "scb" command) */
 /*-----------------------------------------------------------------------*/
 
+#if defined(XC_WIN32) && !defined(TCL_WRAPPER)
+
+int rgb_alloccolor(int red, int green, int blue)
+{
+   return RGB(red >> 8, green >> 8, blue >> 8);
+}
+
+#else
+
 int rgb_alloccolor(int red, int green, int blue)
 {
    XColor newcolor;
@@ -798,6 +852,8 @@ int rgb_alloccolor(int red, int green, int blue)
    return pixval;
 }
 
+#endif
+
 /*----------------------------------------------------------------------*/
 /* Query a color by name to see if it is in the color table.		*/
 /* Return the table index (NOT the pixel value) of the entry, 		*/
@@ -825,12 +881,57 @@ void makecursors()
 {
    XColor fgcolor, bgcolor;
    Window win = areawin->window;
+#ifdef TCL_WRAPPER
+   Tk_Uid fg_uid, bg_uid;
+#endif
 
    bgcolor.pixel = BACKGROUND;
    fgcolor.pixel = FOREGROUND;
-   XQueryColor(dpy, cmap, &fgcolor);
-   XQueryColor(dpy, cmap, &bgcolor);
+   XQueryColors(dpy, cmap, &fgcolor, 1);
+   XQueryColors(dpy, cmap, &bgcolor, 1);
 
+#ifdef TCL_WRAPPER
+
+#ifdef XC_WIN32
+#define Tk_GetCursorFromData CreateW32Cursor
+#endif
+
+   fg_uid = Tk_GetUid(Tk_NameOfColor(&fgcolor));
+   bg_uid = Tk_GetUid(Tk_NameOfColor(&bgcolor));
+
+   ARROW = (Cursor)Tk_GetCursorFromData(xcinterp, Tk_IdToWindow(dpy, win),
+	arrow_bits, arrowmask_bits, arrow_width, arrow_height, arrow_x_hot, arrow_y_hot,
+	fg_uid, bg_uid);
+   CROSS = (Cursor)Tk_GetCursorFromData(xcinterp, Tk_IdToWindow(dpy, win),
+	cross_bits, crossmask_bits, cross_width, cross_height, cross_x_hot, cross_y_hot,
+	fg_uid, bg_uid);
+   SCISSORS = (Cursor)Tk_GetCursorFromData(xcinterp, Tk_IdToWindow(dpy, win),
+	scissors_bits, scissorsmask_bits, scissors_width, scissors_height,
+	scissors_x_hot, scissors_y_hot, fg_uid, bg_uid);
+   EDCURSOR = (Cursor)Tk_GetCursorFromData(xcinterp, Tk_IdToWindow(dpy, win),
+	exx_bits, exxmask_bits, exx_width, exx_height, exx_x_hot, exx_y_hot,
+	fg_uid, bg_uid);
+   COPYCURSOR = (Cursor)Tk_GetCursorFromData(xcinterp, Tk_IdToWindow(dpy, win),
+	copy_bits, copymask_bits, copy_width, copy_height, copy_x_hot, copy_y_hot,
+	fg_uid, bg_uid);
+   ROTATECURSOR = (Cursor)Tk_GetCursorFromData(xcinterp, Tk_IdToWindow(dpy, win),
+	rot_bits, rotmask_bits, rot_width, rot_height, circle_x_hot, circle_y_hot,
+	fg_uid, bg_uid);
+   QUESTION = (Cursor)Tk_GetCursorFromData(xcinterp, Tk_IdToWindow(dpy, win),
+	question_bits, questionmask_bits, question_width, question_height,
+	question_x_hot, question_y_hot, fg_uid, bg_uid);
+   CIRCLE = (Cursor)Tk_GetCursorFromData(xcinterp, Tk_IdToWindow(dpy, win),
+	circle_bits, circlemask_bits, circle_width, circle_height, circle_x_hot,
+	circle_y_hot, fg_uid, bg_uid);
+   HAND = (Cursor)Tk_GetCursorFromData(xcinterp, Tk_IdToWindow(dpy, win),
+	hand_bits, handmask_bits, hand_width, hand_height, hand_x_hot, hand_y_hot,
+	fg_uid, bg_uid);
+
+#ifdef XC_WIN32
+#undef Tk_GetCursorFromData
+#endif
+
+#else
    ARROW = XCreatePixmapCursor(dpy, XCreateBitmapFromData(dpy, win, arrow_bits,
 	arrow_width, arrow_height), XCreateBitmapFromData(dpy, win, arrowmask_bits,
 	arrow_width, arrow_height), &fgcolor, &bgcolor, arrow_x_hot, arrow_y_hot);
@@ -857,11 +958,13 @@ void makecursors()
    CIRCLE = XCreatePixmapCursor(dpy, XCreateBitmapFromData(dpy, win, circle_bits,
 	circle_width, circle_height), XCreateBitmapFromData(dpy, win, circlemask_bits,
 	circle_width, circle_height), &fgcolor, &bgcolor, circle_x_hot, circle_y_hot);
-   TEXTPTR = XCreateFontCursor(dpy, XC_xterm);
-   WAITFOR = XCreateFontCursor(dpy, XC_watch);
    HAND = XCreatePixmapCursor(dpy, XCreateBitmapFromData(dpy, win, hand_bits,
 	hand_width, hand_height), XCreateBitmapFromData(dpy, win, handmask_bits,
 	hand_width, hand_height), &fgcolor, &bgcolor, hand_x_hot, hand_y_hot);
+#endif
+
+   TEXTPTR = XCreateFontCursor(dpy, XC_xterm);
+   WAITFOR = XCreateFontCursor(dpy, XC_watch);
 
    XRecolorCursor(dpy, TEXTPTR, &fgcolor, &bgcolor);
 }
@@ -968,6 +1071,8 @@ XCWindowData *create_new_window()
    newwindow->event_mode = NORMAL_MODE;
    newwindow->attachto = FALSE;
    newwindow->color = DEFAULTCOLOR;
+   newwindow->gccolor = 0;
+   newwindow->gctype = 0;
    newwindow->time_id = 0;
    newwindow->vscale = 1;
    newwindow->pcorner.x = newwindow->pcorner.y = 0;
@@ -1026,7 +1131,7 @@ void pre_initialize()
    xobjs.pagelist[0]->gridspace = DEFAULTGRIDSPACE;
    xobjs.pagelist[0]->snapspace = DEFAULTSNAPSPACE;
    xobjs.pagelist[0]->drawingscale.x = xobjs.pagelist[0]->drawingscale.y = 1;
-   xobjs.pagelist[0]->coordstyle = FRAC_INCH;
+   xobjs.pagelist[0]->coordstyle = INTERNAL;
    xobjs.pagelist[0]->pagesize.x = 612;
    xobjs.pagelist[0]->pagesize.y = 792;
 
@@ -1101,10 +1206,10 @@ static Tcl_ObjType tclHandleType = {
 
 static void
 UpdateStringOfHandle(objPtr)
-    register Tcl_Obj *objPtr;   /* Int object whose string rep to update. */
+    Tcl_Obj *objPtr;   /* Int object whose string rep to update. */
 {
     char buffer[TCL_INTEGER_SPACE];
-    register int len;
+    int len;
 
     sprintf(buffer, "H%08lX", objPtr->internalRep.longValue);
     len = strlen(buffer);
@@ -1119,12 +1224,12 @@ UpdateStringOfHandle(objPtr)
 static int
 SetHandleFromAny(interp, objPtr)
     Tcl_Interp *interp;         /* Used for error reporting if not NULL. */
-    register Tcl_Obj *objPtr;   /* The object to convert. */
+    Tcl_Obj *objPtr;   /* The object to convert. */
 {  
     Tcl_ObjType *oldTypePtr = objPtr->typePtr;
     char *string, *end;
     int length;
-    register char *p;
+    char *p;
     long newLong;
     pushlistptr newstack = NULL;
 
@@ -1254,9 +1359,9 @@ nexthier:
 
 Tcl_Obj *
 Tcl_NewHandleObj(optr)
-    register void *optr;      /* Int used to initialize the new object. */
+    void *optr;      /* Int used to initialize the new object. */
 {
-    register Tcl_Obj *objPtr;
+    Tcl_Obj *objPtr;
 
     objPtr = Tcl_NewObj();
     objPtr->bytes = NULL;
@@ -1271,10 +1376,10 @@ Tcl_NewHandleObj(optr)
 int
 Tcl_GetHandleFromObj(interp, objPtr, handlePtr)
     Tcl_Interp *interp;		/* Used for error reporting if not NULL. */
-    register Tcl_Obj *objPtr;	/* The object from which to get a int. */
-    register void **handlePtr;	/* Place to store resulting int. */
+    Tcl_Obj *objPtr;	/* The object from which to get a int. */
+    void **handlePtr;	/* Place to store resulting int. */
 {
-    register long l;
+    long l;
     int result;
 
     if (objPtr->typePtr != &tclHandleType) {
@@ -1368,7 +1473,7 @@ void post_initialize()
 
    xobjs.save_interval = appdata.timeout;
    xobjs.timeout_id = xcAddTimeOut(app, 60000 * xobjs.save_interval,
-	(xcTimeOutProc)savetemp, NULL);
+	savetemp, NULL);
 }
 
 /*----------------------------------------------------------------------*/
