@@ -14,6 +14,14 @@ typedef unsigned int	u_int;
 typedef unsigned long	u_long;
 #endif
 
+#ifdef XC_WIN32
+#ifdef TCL_WRAPPER
+#include "tkwin32.h"
+#else
+#include "xcwin32.h"
+#endif
+#endif
+
 /*----------------------------------------------------------------------*/
 /* Graphics functions defined for X11 (i.e., not OpenGL)		*/
 /*----------------------------------------------------------------------*/
@@ -119,8 +127,10 @@ ERROR: Cannot compile without knowing the size of a pointer.  See xcircuit.h.
 #define XtnSetArg(a,b)  	XtSetArg(wargs[n], a, b); n++
 #define abs(a)			((a) < 0 ? -(a) : (a))
 #define sign(a)			((a) <= 0 ? -1 : 1)
+#ifndef min
 #define max(a,b)		((a) < (b) ? (b) : (a))
 #define min(a,b)		((a) < (b) ? (a) : (b))
+#endif
 
 /*----------------------------------------------------------------------*/
 /* Lengthier define constructs						*/
@@ -297,8 +307,8 @@ enum editmode {
   RESCALE_MODE,		/* Interactive element rescaling box */
   CATALOG_MODE,		/* On a library page, library directory, or page directory */
   CATTEXT_MODE,		/* Editing an existing object name in the library */
-  FONTCAT_MODE,		/* Accessing the font character page from TEXT2_MODE */
-  EFONTCAT_MODE,	/* Accessing the font character page from TEXT3_MODE */
+  FONTCAT_MODE,		/* Accessing the font character page from TEXT_MODE */
+  EFONTCAT_MODE,	/* Accessing the font character page from ETEXT_MODE */
   TEXT_MODE,		/* Creating a new label */
   WIRE_MODE,		/* Creating a new polygon (wire) */
   BOX_MODE,		/* Creating a new box */
@@ -421,6 +431,9 @@ enum loadmodes {IMPORT = 1, PSBKGROUND, SCRIPT, RECOVER,
 #define STIP1 64
 #define STIP2 128
 #define FILLSOLID 224  /* = 32 + 64 + 128 */
+#ifdef OPAQUE
+#undef OPAQUE
+#endif
 #define OPAQUE 256
 #define BBOX 512
 #define SQUARECAP 1024
