@@ -14,6 +14,7 @@
 #include <errno.h>
 #include <limits.h>
 
+#ifndef XC_WIN32
 #include <X11/Intrinsic.h>
 #include <X11/StringDefs.h>
 #include <X11/Xutil.h>
@@ -21,6 +22,7 @@
 #include "Xw/Xw.h"
 #include "Xw/MenuBtn.h"
 #include "Xw/PopupMgr.h"
+#endif
 
 /*----------------------------------------------------------------------*/
 /* Local includes							*/
@@ -132,6 +134,8 @@ void dotoolbar(xcWidget w, caddr_t clientdata, caddr_t calldata)
 /* Overwrite the toolbar pixmap for color or stipple entries	*/
 /*--------------------------------------------------------------*/
 
+#ifndef XC_WIN32
+
 void overdrawpixmap(xcWidget button)
 {
    xcWidget pbutton;
@@ -176,6 +180,8 @@ void overdrawpixmap(xcWidget button)
    }
 }
 
+#endif
+
 #else
 #define overdrawpixmap(a)
 #endif	/* XPM */
@@ -923,7 +929,7 @@ void highlightexcl(xcWidget widget, int func, int value)
 
 	 default:
 	    for (titem = ToolBar; titem < ToolBar + toolbuttons; titem++) {
-	       if (func == (int)(titem->passeddata)) {
+	       if (func == (pointertype)(titem->passeddata)) {
                   self = XtNameToWidget(parent, titem->name);
 	          break;
 	       }
